@@ -1,12 +1,7 @@
-package Devel::REPL;
-BEGIN {
-  $Devel::REPL::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::VERSION = '1.003024';
-}
-# git description: v1.003023-4-g7a9167f
+package Devel::REPL; # git description: v1.003026-23-gb072305
+# ABSTRACT: A modern perl interactive shell
 
+our $VERSION = '1.003027';
 
 use Term::ReadLine;
 use Moose;
@@ -157,9 +152,21 @@ sub print {
   print $fh "\n" if $self->term->ReadLine =~ /Gnu/;
 }
 
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::REPL - a modern perl interactive shell
+Devel::REPL - A modern perl interactive shell
+
+=head1 VERSION
+
+version 1.003027
 
 =head1 SYNOPSIS
 
@@ -207,7 +214,8 @@ which means a single statement doesn't require the semicolon. You can add one
 if you like, though.
 
 If you followed the first example in the L</"SYNOPSIS"> above, you'll have the
-History and LexEnv plugins loaded (and there are many more available).
+L<History|Devel::REPL::Plugin::History> and L<LexEnv|Devel::REPL::Plugin::LexEnv>
+plugins loaded (and there are many more available).
 Although the shell might support "up-arrow" history, the History plugin adds
 "bang" history to that so you can re-execute chosen commands (with e.g.
 C<!53>). The LexEnv plugin ensures that lexical variables declared with the
@@ -236,7 +244,6 @@ To quit from the shell, hit C<Ctrl+D> or C<Ctrl+C>.
   MSWin32 NOTE: control keys won't work if TERM=dumb
   because readline functionality will be disabled.
 
-
 =head2 Run Control Files
 
 For particular projects you might well end up running the same commands each
@@ -337,7 +344,7 @@ output, or even add commands to the shell environment.
 
 A number of plugins ship with C<Devel::REPL>, and more are available on the
 CPAN. Some of the shipped plugins are loaded in the default profile, mentioned
-above.  These plugins can be loaded in your C<< $HOME/.re.pl/repl.rc >> like:
+above.  These plugins can be loaded in your F< $HOME/.re.pl/repl.rc > like:
 
   load_plugin qw( CompletionDriver::Global DumpHistory );
 
@@ -373,27 +380,49 @@ distribution interactively (e.g. C<cpanm --interactive Devel::REPL>).
 
 =over 4
 
-=item * Completion plugin - extensible tab completion
+=item *
 
-=item * DDS plugin - better format results with Data::Dump::Streamer
+Completion plugin - extensible tab completion
 
-=item * DDC plugin - even better format results with Data::Dumper::Concise
+=item *
 
-=item * INC completion driver - tab complete module names in use and require
+DDS plugin - better format results with Data::Dump::Streamer
 
-=item * Interrupt plugin - traps SIGINT to kill long-running lines
+=item *
 
-=item * Keywords completion driver - tab complete Perl keywords and operators
+DDC plugin - even better format results with Data::Dumper::Concise
 
-=item * LexEnv plugin - variables declared with "my" persist between statements
+=item *
 
-=item * MultiLine::PPI plugin - continue reading lines until all blocks are closed
+INC completion driver - tab complete module names in use and require
 
-=item * Nopaste plugin - upload a session\'s input and output to a Pastebin
+=item *
 
-=item * PPI plugin - PPI dumping of Perl code
+Interrupt plugin - traps SIGINT to kill long-running lines
 
-=item * Refresh plugin - automatically reload libraries with Module::Refresh
+=item *
+
+Keywords completion driver - tab complete Perl keywords and operators
+
+=item *
+
+LexEnv plugin - variables declared with "my" persist between statements
+
+=item *
+
+MultiLine::PPI plugin - continue reading lines until all blocks are closed
+
+=item *
+
+Nopaste plugin - upload a session\'s input and output to a Pastebin
+
+=item *
+
+PPI plugin - PPI dumping of Perl code
+
+=item *
+
+Refresh plugin - automatically reload libraries with Module::Refresh
 
 =back
 
@@ -403,36 +432,101 @@ Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Shawn M Moore Chris Marshall Matt S Trout Oliver Gorwits יובל קוג'מן (Yuval Kogman) Arthur Axel 'fREW' Schmidt Andrew Alexis Sukrieh Tomas Doran (t0m) epitaph Norbert Buchmuller Jesse Luehrs Dave Houston Dagfinn Ilmari Mannsåker Zakariyya Mughal Ryan Niebur Justin Hunter Ash Berlin naquad Stevan Little
+
 =over 4
 
-=item Stevan Little - stevan (at) iinteractive.com
+=item *
 
-=item Alexis Sukrieh - sukria+perl (at) sukria.net
+Karen Etheridge <ether@cpan.org>
 
-=item epitaph
+=item *
 
-=item mgrimes - mgrimes (at) cpan dot org
+Shawn M Moore <code@sartak.org>
 
-=item Shawn M Moore - sartak (at) gmail.com
+=item *
 
-=item Oliver Gorwits - oliver on irc.perl.org
+Chris Marshall <devel.chm.01@gmail.com>
 
-=item Andrew Moore - C<< <amoore@cpan.org> >>
+=item *
 
-=item Norbert Buchmuller C<< <norbi@nix.hu> >>
+Matt S Trout <mst@shadowcat.co.uk>
 
-=item Dave Houston C<< <dhouston@cpan.org> >>
+=item *
 
-=item Chris Marshall
+Oliver Gorwits <oliver@cpan.org>
 
-=item Karen Etheridge C<< <ether@cpan.org> >>
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+
+=item *
+
+Andrew Moore <amoore@cpan.org>
+
+=item *
+
+Alexis Sukrieh <sukria+perl@sukria.net>
+
+=item *
+
+Tomas Doran (t0m) <bobtfish@bobtfish.net>
+
+=item *
+
+epitaph <unknown>
+
+=item *
+
+Norbert Buchmuller <norbi@nix.hu>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Dave Houston <dhouston@cpan.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Zakariyya Mughal <zaki.mughal@gmail.com>
+
+=item *
+
+Ryan Niebur <ryan@debian.org>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Ash Berlin <ash_github@firemirror.com>
+
+=item *
+
+naquad <naquad@bd8105ee-0ff8-0310-8827-fb3f25b6796d>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
 
 =back
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software under the same terms as perl itself
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
