@@ -1,11 +1,9 @@
 package Devel::REPL::Error;
-BEGIN {
-  $Devel::REPL::Error::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Error::VERSION = '1.003024';
-}
+
+our $VERSION = '1.003027';
+
 use Moose;
+use namespace::autoclean;
 
 # FIXME get nothingmuch to refactor and release his useful error object
 
@@ -27,5 +25,3 @@ sub stringify {
   sprintf "%s: %s", $self->type, $self->message;
 }
 __PACKAGE__
-
-__END__
