@@ -1,15 +1,12 @@
-package Devel::REPL::Plugin;
-BEGIN {
-  $Devel::REPL::Plugin::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Plugin::VERSION = '1.003024';
-}
-
 use strict;
 use warnings;
+package Devel::REPL::Plugin;
+
+our $VERSION = '1.003027';
+
 use Devel::REPL::Meta::Plugin;
 use Moose::Role ();
+use namespace::autoclean;
 
 sub import {
   my $target = caller;
