@@ -1,12 +1,13 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::DDC;
-BEGIN {
-  $Devel::REPL::Plugin::DDC::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::DDC::VERSION = '1.003026';
+# ABSTRACT: Format results with Data::Dumper::Concise
+
+our $VERSION = '1.003027';
+
 use Devel::REPL::Plugin;
 use Data::Dumper::Concise ();
+use namespace::autoclean;
 
 around 'format_result' => sub {
   my $orig = shift;
@@ -29,13 +30,17 @@ around 'format_result' => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::DDC - Format results with Data::Dumper::Concise
 
 =head1 VERSION
 
-version 1.003026
+version 1.003027
 
 =head1 SYNOPSIS
 
@@ -55,4 +60,15 @@ version 1.003026
 
  $
 
+=head1 AUTHOR
+
+Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
