@@ -1,15 +1,12 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::Nopaste;
-BEGIN {
-  $Devel::REPL::Plugin::Nopaste::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Plugin::Nopaste::VERSION = '1.003024';
-}
+# ABSTRACT: #nopaste to upload session's input and output
+
+our $VERSION = '1.003027';
 
 use Devel::REPL::Plugin;
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints 'enum';
 use namespace::autoclean;
 use Scalar::Util qw(blessed);
 
@@ -102,10 +99,18 @@ sub command_pastetitle {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::Nopaste - #nopaste to upload session's input and output
 
+=head1 VERSION
+
+version 1.003027
+
 =head1 COMMANDS
 
 This module provides these commands to your Devel::REPL shell:
@@ -122,7 +127,7 @@ the nopaste site. For example:
 
 C<#pastetitle example of some code>
 
-defaults to 'Devel::REPL session'
+defaults to C<'Devel::REPL session'>.
 
 =head1 CONFIGURATION
 
@@ -140,13 +145,9 @@ The default of commenting out the output would be set like this:
 
 C<< $_REPL->nopaste_format( 'comment_output' ); >>
 
-These options can be set during a Devel::REPL session, but only affect
+These options can be set during a L<Devel::REPL> session, but only affect
 the future parts of the session, not the past parts.
 
-=head1 AUTHOR
-
-Shawn M Moore, C<< <sartak at gmail dot com> >>
-
 =head1 CONTRIBUTORS
 
 =over 4
@@ -155,5 +156,15 @@ Shawn M Moore, C<< <sartak at gmail dot com> >>
 
 =back
 
-=cut
+=head1 AUTHOR
 
+Shawn M Moore, C<< <sartak at gmail dot com> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
