@@ -6,13 +6,14 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::ReadLineHistory;
-BEGIN {
-  $Devel::REPL::Plugin::ReadLineHistory::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::ReadLineHistory::VERSION = '1.003026';
+# ABSTRACT: Integrate history with the facilities provided by L<Term::ReadLine>
+
+our $VERSION = '1.003027';
+
 use Devel::REPL::Plugin;
 use File::HomeDir;
 use File::Spec;
+use namespace::autoclean;
 
 my $hist_file = $ENV{PERLREPL_HISTFILE} ||
     File::Spec->catfile(File::HomeDir->my_home, '.perlreplhist');
@@ -73,13 +74,17 @@ around 'run' => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::ReadLineHistory - Integrate history with the facilities provided by L<Term::ReadLine>
 
 =head1 VERSION
 
-version 1.003026
+version 1.003027
 
 =head1 DESCRIPTION
 
@@ -115,4 +120,15 @@ Work is underway to make use of either L<History|Devel::REPL::Plugin::History> o
 L<ReadLineHistory|Devel::REPL::Plugin::ReadHistory>> consistent for expansion with either the
 L<Term::ReadLine::Gnu> support or L<Term::ReadLine::Perl>.
 
+=head1 AUTHOR
+
+Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
